package com.ruoyi.project.sems.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.sems.mapper.TSpecdevGlMapper;
import com.ruoyi.project.sems.domain.TSpecdevGl;
import com.ruoyi.project.sems.service.ITSpecdevGlService;

/**
 * 特种设备锅炉台账Service业务层处理
 *
 * @author ruoyi
 * @date 2021-07-21
 */
@Service("tSpecdevGlService")
public class TSpecdevGlServiceImpl  implements ITSpecdevGlService
{
    @Autowired
    private TSpecdevGlMapper tSpecdevGlMapper;

    /**
     * 查询特种设备锅炉台账
     *
     * @param id 特种设备锅炉台账ID
     * @return 特种设备锅炉台账
     */
    @Override
    public TSpecdevGl selectTSpecdevGlById(Long id)
    {
        return tSpecdevGlMapper.selectTSpecdevGlById(id);
    }

    /**
     * 查询特种设备锅炉台账列表
     *
     * @param tSpecdevGl 特种设备锅炉台账
     * @return 特种设备锅炉台账
     */
    @Override
    public List<TSpecdevGl> selectTSpecdevGlList(TSpecdevGl tSpecdevGl)
    {
        return tSpecdevGlMapper.selectTSpecdevGlList(tSpecdevGl);
    }

    @Override
    public List<TSpecdevGl> selectTSpecdevGlListByYear(TSpecdevGl tSpecdevGl) {
        return  tSpecdevGlMapper.selectTSpecdevGlListByYear(tSpecdevGl);
    }

    /**
     * 新增特种设备锅炉台账
     *
     * @param tSpecdevGl 特种设备锅炉台账
     * @return 结果
     */
    @Override
    public int insertTSpecdevGl(TSpecdevGl tSpecdevGl)
    {
        return tSpecdevGlMapper.insertTSpecdevGl(tSpecdevGl);
    }

    /**
     * 修改特种设备锅炉台账
     *
     * @param tSpecdevGl 特种设备锅炉台账
     * @return 结果
     */
    @Override
    public int updateTSpecdevGl(TSpecdevGl tSpecdevGl)
    {
        return tSpecdevGlMapper.updateTSpecdevGl(tSpecdevGl);
    }

    /**
     * 批量删除特种设备锅炉台账
     *
     * @param ids 需要删除的特种设备锅炉台账ID
     * @return 结果
     */
    @Override
    public int deleteTSpecdevGlByIds(Long[] ids)
    {
        return tSpecdevGlMapper.deleteTSpecdevGlByIds(ids);
    }

    /**
     * 删除特种设备锅炉台账信息
     *
     * @param id 特种设备锅炉台账ID
     * @return 结果
     */
    @Override
    public int deleteTSpecdevGlById(Long id)
    {
        return tSpecdevGlMapper.deleteTSpecdevGlById(id);
    }

    @Override
    public void duplicateTSpecdevGl() {
        tSpecdevGlMapper.duplicateTSpecdevGl();
    }
}
